@@ -6,6 +6,7 @@ import importlib
 import json
 import os
 import warnings
+import logging
 from typing import Tuple, Optional
 
 import boto
@@ -89,11 +90,8 @@ def get_local_model_path():
 
 LOCAL_MODEL_PATH = get_local_model_path()
 
-assert LOCAL_MODEL_PATH is not None, \
-    "SPACER_LOCAL_MODEL_PATH environmental variable must be set."
-
-assert os.path.exists(LOCAL_MODEL_PATH), "LOCAL_MODEL_PATH is set, " \
-                                         "but path doesn't exist"
+HAS_LOCAL_MODEL_PATH = LOCAL_MODEL_PATH is not None and \
+                       os.path.exists(LOCAL_MODEL_PATH)
 
 TASKS = [
     'extract_features',
@@ -133,20 +131,33 @@ MIN_TRAINIMAGES = 10
 # Check access to select which tests to run.
 HAS_CAFFE = importlib.util.find_spec("caffe") is not None
 
-conn = get_s3_conn()
 try:
-    bucket = conn.get_bucket('spacer-test', validate=True)
+    conn = get_s3_conn()
     HAS_S3_TEST_ACCESS = True
-except boto.exception.S3ResponseError as err:  # pragma: no cover
-    print("-> No connection to spacer-test bucket, can't run remote tests")
-    HAS_S3_TEST_ACCESS = False
-
-try:
-    bucket = conn.get_bucket('spacer-tools', validate=True)
     HAS_S3_MODEL_ACCESS = True
-except boto.exception.S3ResponseError as err:  # pragma: no cover
-    print("-> No connection to spacer-tools bucket, can't download models")
+except boto.exception.NoAuthHandlerFound as err:  # pragma: no cover
+    conn = None
+    logging.info("-> No connection to AWS, can't run remote tests.")
+    HAS_S3_TEST_ACCESS = False
     HAS_S3_MODEL_ACCESS = False
 
+if HAS_S3_TEST_ACCESS:
+    try:
+        bucket = conn.get_bucket('spacer-test', validate=True)
+        HAS_S3_TEST_ACCESS = True
+    except boto.exception.S3ResponseError as err:  # pragma: no cover
+        logging.info("-> No connection to spacer-test bucket, "
+                     "can't run remote tests.")
+        HAS_S3_TEST_ACCESS = False
+
+if HAS_S3_MODEL_ACCESS:
+    try:
+        bucket = conn.get_bucket('spacer-tools', validate=True)
+        HAS_S3_MODEL_ACCESS = True
+    except boto.exception.S3ResponseError as err:  # pragma: no cover
+        logging.info("-> No connection to spacer-tools bucket, "
+                     "can't download models.")
+        HAS_S3_MODEL_ACCESS = False
+
 # Add margin to avoid warnings when running unit-test.
 Image.MAX_IMAGE_PIXELS = MAX_IMAGE_PIXELS + 20000
